@@ -3,8 +3,7 @@
 import re
 import time
 import warnings
-
-from vk.utils import make_handy
+import requests
 
 try:
     from urlparse import urlparse, parse_qsl  # Python 2
@@ -16,7 +15,8 @@ try:
 except ImportError:
     import json
 
-import requests
+
+REDIRECT_URI = 'https://oauth.vk.com/blank.html'
 
 # vk.com API Errors
 INTERNAL_SERVER_ERROR = 10  # Invalid access token
@@ -73,17 +73,21 @@ class APISession(object):
             'utf8': '1',
             'email': self.user_login,
             'pass': self.user_password,
+            'redirect_uri': REDIRECT_URI
         }
 
         response = session.post('https://login.vk.com', login_data)
 
-        if 'remixsid' in session.cookies:
+        if 'remixsid' in session.cookies or 'remixsid6' in session.cookies:
             pass
         elif 'sid=' in response.url:
-            raise VkAuthorizationError('Authorization error (captcha)')
+            self.auth_captcha_is_needed(response.content, session)
+        elif 'act=authcheck' in response.url:
+            self.auth_code_is_needed(response.content, session)
         elif 'security_check' in response.url:
-            raise VkAuthorizationError('Authorization error (phone number is needed)')
-        else:
+            self.phone_number_is_needed(response.content, session)
+        else:           
+            
             raise VkAuthorizationError('Authorization error (bad password)')
 
         # OAuth2
@@ -173,7 +177,28 @@ class APISession(object):
         Reload this in child
         """
         raise VkAPIMethodError(error_data)
-
+    
+    def auth_code_is_needed(self, content, session):
+        """
+        Default behavior on 2-AUTH CODE is to raise exception
+        Reload this in child
+        """           
+        raise VkAuthorizationError('Authorization error (2-factor code is needed)')
+    
+    def auth_captcha_is_needed(self, content, session):
+        """
+        Default behavior on CAPTCHA is to raise exception
+        Reload this in child
+        """              
+        raise VkAuthorizationError('Authorization error (captcha)')
+    
+    def phone_number_is_needed(self, content, session):
+        """
+        Default behavior on PHONE NUMBER is to raise exception
+        Reload this in child
+        """              
+        raise VkAuthorizationError('Authorization error (phone number is needed)')        
+    
 
 class APIMethod(object):
     __slots__ = ['_api_session', '_method_name']
